<?php

namespace Drupal\mcapi_credcom;
use \CreditCommons\TransactionInterface;
use Drupal\mcapi_credcom\Functions;

/**
 * An object to represent the credit commons data which doesn't fit in the transaction.
 */
class CredCom {

  const MCAPI_CREDCOM_STATE_MAP = [
    #drupal => credcom
    'validated' => TransactionInterface::STATE_VALIDATED,
    'pending' => TransactionInterface::STATE_PENDING,
    'done' => TransactionInterface::STATE_COMPLETED,
    'erased' => TransactionInterface::STATE_ERASED,
  ];

  private $database;
  public $trunkwardNode;
  public string $state;
  public int $version;
  public array $additional = [];

  /**
   * Constructor
   */
  public function __construct(
    public string $uuid,
    public string $type,
    public array $entries
    ) {
    $this->loadObj();
    $this->state = 'init';
    $this->version = -1;
  }

  static function load($uuid) {
    $result = \Drupal::database()->select('mcapi_credcom_data', 'e')
      ->fields('e', ['uuid', 'version', 'state', 'type', 'entries'])
      ->condition('uuid', $uuid, 'IN')
      ->execute()->fetch();
    if ($result) {
      require_once __DIR__.'/EndPoint.php';// Where the Account and AccountRemote classes are defined.
      $credcom = new static($result->uuid, $result->type, unserialize($result->entries));
      $credcom->state = $result->state;
      $credcom->version = $result->version;
      return $credcom;
    }
  }

  function changeState(string $credcom_state, $relay = FALSE) {
    $this->version++;
    $this->state = $credcom_state;
    if ($relay) {
      $this->trunkwardNode->transactionChangeState($this->uuid, $credcom_state);
    }
  }

  /**
   * @param int $serial
   */
  function update(int $serial) {
    $this->database->update('mcapi_credcom_data')
      ->fields(['state'=> $this->state, 'version' => $this->version])
      ->condition('uuid', $this->uuid)
      ->execute();
    $this->saveHash($serial);
  }

  /**
   * @param int $serial
   */
  function insert(int $serial) {
    $vals = ['uuid' => $this->uuid, 'state'=> $this->state, 'type'=> $this->type, 'version' => $this->version, 'entries' => serialize($this->entries)];
    $this->database->insert('mcapi_credcom_data')
      ->fields($vals)
      ->execute();
    $this->saveHash($serial);
  }

  /**
   * Seems clumsy to pass the $serial through the insert/update function
   * @param int $serial
   */
  function saveHash(int $serial) {
    if ($this->version) {
      $hash_string = $this->getHashString($this->uuid, $this->state, $this->version, $this->entries);
      $this->database->insert('mcapi_credcom_hashchain')
        ->fields([
          'uuid' => $this->uuid,
          'version' => $this->version,
          'hash' => md5($hash_string),
          'hash_string' => $hash_string
        ])
        ->execute();
    }
  }

  // todo replace this with the cc-php-lib
  private function getHashString(string $uuid, string $state, int $version, array $entries) : string {
    $rows = [];
    $remote_wid = \Drupal::config('mcapi_credcom.settings')->get('wallet_id');
    foreach ($entries as $e) {
      if (Functions::credcomPathIsLocal($e->payee) xor Functions::credcomPathIsLocal($e->payer)) {
        // All quants are trunkwardQuants
        $rows[] = $e->quant.'|'.$e->description;
      }
    }
    return join('|', [
      Functions::getlastHash(),
      $uuid,
      $state,
      join('|', $rows),
      $version,
    ]);
  }

  function workflow() {
    return $this->trunkwardNode->getWorkflows()[$this->type];
  }

  function __sleep() {
    return ['state', 'version', 'uuid', 'type', 'entries'];
  }

  function __wakeup() {
    $this->loadObj();
  }

  private function loadObj() {
    $this->database = \Drupal::database();
    $this->trunkwardNode = \Drupal::service('mcapi_credcom.trunkward_node');
  }

}
