<?php

namespace Drupal\mcapi_credcom\Plugin\Action;

use Drupal\mcapi_credcom\CredCom;
use Drupal\mcapi_credcom\Functions;
use Drupal\mcapi\Plugin\TransactionActionBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Changes the transaction state to 'erased'.
 *
 * @Action(
 *   id = "mcapi_transaction.remote_finalise_action",
 *   label = @Translation("Finalise a remote transaction"),
 *   type = "mcapi_transaction"
 * )
 */
class Finalise extends TransactionActionBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $elements = parent::buildConfigurationForm($form, $form_state);
    unset($elements['states'], $elements['access']);
    return $elements;
  }

  public function access($transaction, AccountInterface $account = NULL, $return_as_object = FALSE) {
    $access = FALSE;
    if ($transaction->state->target_id == 'pending' && Functions::isRemote($transaction)) {
      $uid = $account->id();
      if (isset($transaction->signatures[$uid]) and $transaction->signatures[$uid] == 0) {
        $access = TRUE;
      }
    }
    return $return_as_object ? AccessResult::allowedIf($access) : $access;
  }

  /**
   * {@inheritdoc}
   */
  public function execute($object = NULL) {
    $dest_state = 'done';
    try {
      $object->set('state', $dest_state);
      $object->credCom->changeState(CredCom::MCAPI_CREDCOM_STATE_MAP[$dest_state], TRUE);
\Drupal::messenger()-addStatus("Set state to ".$object->credCom->state);
    }
    catch (Throwable $e) {
      \Drupal::messenger()->addError(t(
        'There was a problem saving the transaction to the network: @message',
        ['@message' => $e->getMessage()]
      ));
      \Drupal::logger('mcapi_credcom')->notice('@notice', ['@notice' => $e->getMessage()]);
    }
    parent::execute($object);

  }

}
