<?php

namespace Drupal\mcapi_credcom\Plugin\Field\FieldWidget;

use Drupal\Core\Field\Plugin\Field\FieldWidget\StringTextfieldWidget;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Component\Utility\NestedArray;

/**
 * Plugin implementation of the wallet selector widget. This widget is not
 * selectable on the EntityFormDisplay edit page. see mcapi_
 *
 * @FieldWidget(
 *   id = "credcom_wallet",
 *   label = @Translation("Remote wallet"),
 *   description = @Translation("A remote wallet name with autocomplete"),
 *   field_types = {
 *     "wallet_reference"
 *   }
 * )
 */
class CredcomWalletWidget extends StringTextfieldWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['value'] = [
      '#title' => $this->t('Remote wallet'),// this shouldn't be rendered,
      '#description' => t('Autocompletes using network data, as far as privacy settings allow.'),
      '#type' => 'textfield',
      '#autocomplete_route_name' => 'mcapi_credcom.wallet_autocomplete',
    ];
    return $element;
  }

  public function extractFormValues(FieldItemListInterface $items, array $form, FormStateInterface $form_state) {
    $field_name = $this->fieldDefinition->getName();
    // Extract the values from $form_state->getValues().
    $key_exists = NULL;
    $values = NestedArray::getValue(
      $form_state->getValues(),
      array_merge($form['#parents'], [$field_name]),
      $key_exists
    );

    if ($key_exists) {
      $items->setValue($values);
      // Put delta mapping in $form_state, so that flagErrors() can use it.
      static::setWidgetState(
        $form['#parents'],
        $field_name,
        $form_state,
        static::getWidgetState($form['#parents'], $field_name, $form_state)
      );
    }
  }


}
