<?php

namespace Drupal\mcapi_forms;

use Drupal\mcapi\Form\TransactionForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\Entity\EntityFormMode;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Render\Element;

/**
 * Form builder for transaction formed designed via the UI.
 */
class FirstPartyTransactionForm extends TransactionForm {

  protected $settings = [];

  function init(FormStateInterface $form_state) {
    parent::init($form_state); // Sets form display
    $mode = $this->getFormDisplay($form_state)->getOriginalMode();
    $this->settings = EntityFormMode::load('mcapi_transaction.'. $mode)
      ->getThirdPartySettings('mcapi_forms');
    if (str_contains($mode, 'bill')) {
      $this->dir = static::DIR_INCOMING;
    }
    if (str_contains($mode, 'credit')) {
      $this->dir = static::DIR_OUTGOING;
    }
    $this->entity->type->target_id = $this->settings['transaction_type'] ?? 'default';
  }

  /**
   * {@inheritDoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['#title'] = $this->settings['title'];
    $twig_template = $this->settings['experience_twig'];
    // If a field is not in the template then set its access to FALSE so it won't fail validation.
    foreach (Element::children($form) as $key) {
      if (!preg_match('/\{\{ ?'.$key.' ?\}\}/', $twig_template)) {
        // hopefully the missing field will have a default value!
        $form[$key]['#access'] = FALSE;
      }
    }
    $form['#twig_template'] = str_replace(["\\r\\n","\\n","\\r"], "<br/>", $twig_template);
    $form['#attached']['library'][] = 'mcapi_forms/display';
    return $form;
  }

  /**
   * {@inheritDoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);
    $actions['submit']['#value'] = $this->settings['experience_button'];
    // @todo check this is working.
    $form['#cache']['contexts'][] = 'user';
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'first_party_transaction_form';
  }

  /**
   * {@inheritDoc}
   */
  public function getEntityFromRouteMatch(RouteMatchInterface $route_match, $entity_type_id) {
    $this->request->query->add(['type' => 'default']);
    return parent::getEntityFromRouteMatch($route_match, $entity_type_id);
  }

  /**
   * {@inheritDoc}
   *
   * Fill in any values not explicitly stated.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // See https://www.drupal.org/forum/support/module-development-and-code-questions/2018-02-08/required-fields-and-not-null-database
    if (!$form_state->getValue('description')) {
       $form_state->setValue('description', ' ');
    }
    parent::validateForm($form, $form_state);
  }

}
