<?php

/**
 * @file
 * Helper functions.
 */
use Drupal\mcapi\Entity\CurrencyInterface;

/**
 * Preprocessor function for theme callback mcapi_limits_absolute.
 */
function template_preprocess_mcapi_limits_absolute(&$vars) {
  $currency = $vars['currency'];
  $wallet = $vars['wallet'];
  $curr_id = $currency->id();
  $limiter = mcapi_limits_wallet_limiter($wallet);
  $vars['wallet_label'] = $wallet->label();
  $summary = $vars['wallet']->getStats($currency->id());
  $vars['balanceformatted'] = ['#markup' => $currency->format($summary->balance)];
  $vars['min'] = $limiter->min($curr_id);
  if (is_null($vars['min'])) {
    $vars['minformatted'] = [];
  }
  else {
    $vars['minformatted'] = ['#markup' => $currency->format($vars['min'])];
    $vars['min'] = $currency->format($vars['min'], CurrencyInterface::DISPLAY_PLAIN);
  }
  $vars['max'] = $limiter->max($curr_id);
  if (is_null($vars['max'])) {
    $vars['maxformatted'] = [];
  }
  else {
    $vars['maxformatted'] = ['#markup' => $currency->format($vars['max'])];
    $vars['max'] = $currency->format($vars['max'], CurrencyInterface::DISPLAY_PLAIN);
  }
  $vars['balance'] = $currency->format($summary->balance, CurrencyInterface::DISPLAY_PLAIN);
}

/**
 * Preprocessor function for theme callback mcapi_limits_relative.
 */
function template_preprocess_mcapi_limits_relative(&$vars) {
  $wallet = $vars['wallet'];
  $limiter = mcapi_limits_wallet_limiter($wallet);
  $balance = $wallet->getStat($vars['currency']->id(), 'balance');
  $vars['wallet_label'] = $wallet->label();
  $vars['earn_limit'] = $limiter->earnLimit($vars['currency']->id(), $balance);
  $vars['spend_limit'] = $limiter->spendLimit($vars['currency']->id(), $balance);

  if (!is_null($vars['spend_limit'])) {
    $vars['spendlimitformatted'] = ['#markup' => $vars['currency']->format($vars['spend_limit'])];
  }
  if (!is_null($vars['earn_limit'])) {
    $vars['earnlimitformatted'] = ['#markup' => $vars['currency']->format($vars['earn_limit'])];
  }
}

/**
 * Preprocessor function for theme callback mcapi_limits_balanced.
 *
 * By design this can only be used if the max and min are equidistant from zero
 * Also because of limitations of the google charts gauge visualisation,
 * this can only be used if the formatted value is numeric.
 */
function template_preprocess_mcapi_limits_balanced(&$vars) {
  $currency = $vars['currency'];
  $wallet = $vars['wallet'];
  $limiter = mcapi_limits_wallet_limiter($wallet);
  $curr_id = $currency->id();
  // The google gauge cannot mask the real number with a formatted value.
  $vars['balance'] = $currency->format(
    $wallet->getStats($curr_id)->balance,
    CurrencyInterface::DISPLAY_PLAIN
  );
  $min = $limiter->min($curr_id);
  $max = $limiter->max($curr_id);
  $vars['min'] = $currency->format($min, CurrencyInterface::DISPLAY_PLAIN);
  $vars['max'] = $currency->format($max, CurrencyInterface::DISPLAY_PLAIN);
  $vars['minformatted'] = $currency->format($min);
  $vars['maxformatted'] = $currency->format($max);
  $vars['wallet_label'] = $wallet->label();
}
