<?php

namespace Drupal\mcapi_limits\Plugin\Limits;

use Drupal\mcapi_limits\Plugin\McapiLimitsBase;
use Drupal\mcapi\Entity\WalletInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * No balance limits.
 *
 * @Limits(
 *   id = "explicit",
 *   label = @Translation("Explicit"),
 *   description = @Translation("Explicit limits")
 * )
 */
class Explicit extends McapiLimitsBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['min'] = [
      '#title' => $this->t('Min'),
      '#description' => t('Leave blank for no minimum limit'),
      '#type' => 'worth_form',
      '#weight' => 0,
      '#default_value' => [
        'curr_id' => $this->currency->id(),
        'value' => $this->configuration['explicit']['min']
      ],
      '#allowed_curr_ids' => [$this->currency->id],
      '#config' => TRUE,
      '#minus' => TRUE, // Allow negative values
    ];
    $form['max'] = [
      '#title' => $this->t('Max'),
      '#description' => t('Leave blank for no maximum limit'),
      '#type' => 'worth_form',
      '#weight' => 1,
      '#default_value' => [
        'curr_id' => $this->currency->id(),
        'value' => $this->configuration['explicit']['max']
      ],
      '#allowed_curr_ids' => [$this->currency->id],
      '#config' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function currencyLimits(WalletInterface $wallet) {
    $conf = $this->configuration['explicit'] ?? [];
    return [
      'min' => $conf['min']??NULL,
      'max' => $conf['max']??NULL,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $defaults = parent::defaultConfiguration();
    $defaults['explicit'] = [
      'min' => -1500,
      'max' => 1500,
    ];
    return $defaults;
  }

  function getWorthFields() {
    return ['min', 'max'];
  }


}
