<?php

namespace Drupal\mcapi_limits\Plugin;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\mcapi\Entity\CurrencyInterface;
use Drupal\Component\Plugin\FallbackPluginManagerInterface;

/**
 * Plugin manager for Wallet limits.
 */
class LimitsPluginManager extends DefaultPluginManager implements FallbackPluginManagerInterface {

  private $plugins;

  /**
   * Constructs the LimitsPluginManager object.
   */
  public function __construct($namespaces, $moduleHandler, $cache_backend) {
    parent::__construct(
      'Plugin/Limits',
      $namespaces,
      $moduleHandler,
      '\Drupal\mcapi_limits\Plugin\McapiLimitsInterface',
      '\Drupal\mcapi_limits\Annotation\Limits'
    );
    $this->setCacheBackend($cache_backend, 'mcapi_limits');
  }

  /**
   * Get the plugin for the given currency.
   *
   * @param CurrencyInterface $currency
   *   The current currency.
   */
  public function createInstanceCurrency(CurrencyInterface $currency) : McapiLimitsBase {
    $settings = $currency->getThirdpartySettings('mcapi_limits');
    $plugin_id = isset($settings['plugin']) ? $settings['plugin'] : 'none';
    return $this->createInstance(
      $plugin_id,
      ['currency' => $currency]
    );
  }

  public function getFallbackPluginId($plugin_id, array $configuration = []) {
    if (isset($configuration['currency'])) {
      $message = 'Missing limits plugin: '.$configuration['currency']->id;
    }
    else {
      $message = 'Missing limits plugin';
    }
    \Drupal::logger('mcapi')->critical($message);
    return 'none';
  }

  public function optionsList() : array {
    foreach ($this->getDefinitions() as $name => $plugin) {
      $options[$name] = $plugin['label'];
    }
    return $options;
  }
}
