<?php

namespace Drupal\mcapi_limits\Plugin\Validation\Constraint;

use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Constraint;
use Drupal\mcapi\Entity\CurrencyInterface;

/**
 * Constraint validator checking whether a wallet is beyond its limits.
 */
class TransactionLimitsConstraintValidator extends ConstraintValidator {

  /**
   * {@inheritdoc}
   */
  public function validate($transaction, Constraint $constraint) {
    if ($transgressions = mcapi_limits_check($transaction)) {
      foreach ($transgressions as $wid => $transgression) {
        $replacements = [
          '%wallet' => $transgression->wallet->label(),
          '@currency' => $transgression->currency->name,
          '%limit' => $transgression->currency->format($transgression->limit, CurrencyInterface::DISPLAY_PLAIN),
          '%excess' => $transgression->currency->format($transgression->diff, CurrencyInterface::DISPLAY_PLAIN)
        ];
        $this->context
          ->buildViolation($constraint->message, $replacements)
          ->atPath('worth.' . $this->currGetDelta($transaction, $transgression->currency->id))
          ->addViolation();
      }
    }
  }

  private function currGetDelta($transaction, $curr_id) : int {
    foreach ($transaction->worth as $delta => $item) {
      if ($item->get('curr_id')) {
        return $delta;
      }
    }
  }

}
