<?php

namespace Drupal\mcapi_limits;

use Drupal\mcapi\Entity\WalletInterface;
use Drupal\mcapi\Entity\TransactionInterface;

/**
 * Holds data for a transgression of balance limits.
 */
abstract class Transgression {

  /**
   * The wallet we are working with.
   * @var \Drupal\mcapi\Entity\Wallet
   */
  public $wallet;

  /**
   * The transaction we are working with.
   * @var \Drupal\mcapi\Entity\Transaction
   */
  public $transaction;

  /**
   * The limit of the account in base units
   * @var int
   */
  public $limit;

  /**
   * The amount transgressed in base units
   * @var int
   */
  public $diff;

  /**
   * The the excessive balance in base units
   * @var int
   */
  public $projected;

  /**
   * The currency
   * @var \Drupal\mcapi\Entity\Currency
   */
  public $currency;

  /**
   * The account balance in base units
   * @var int
   */
  public $balance;


  /**
   * Constructor.
   */
  public function __construct(TransactionInterface $transaction, $worth_delta, WalletInterface $wallet, int $balance, int $limit, int $projected) {
    $this->transaction = $transaction;
    $this->wallet = $wallet;
    $this->projected = $projected;
    $this->limit = $limit;
    $this->diff = $projected - $limit;
    $this->currency = $transaction->worth->get($worth_delta)->currency;
    $this->balance = $wallet->getStats($this->currency->id)->balance;
  }

}
