<?php

namespace Drupal\mcapi_signatures\Plugin\Action;

use Drupal\mcapi\Entity\TransactionInterface;
use Drupal\mcapi\Plugin\TransactionActionBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Changes the transaction state from pending to 'done'.
 *
 * @Action(
 *   id = "mcapi_transaction.signoff_action",
 *   label = @Translation("Sign off a transaction"),
 *   type = "mcapi_transaction"
 * )
 */
class SignOff extends TransactionActionBase {

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $elements = parent::buildConfigurationForm($form, $form_state);
    unset($elements['states']);
    return $elements;
  }

  /**
   * {@inheritDoc}
   */
  protected function accessState(TransactionInterface $transaction, AccountInterface $account) : bool {
    return $transaction->state->target_id == 'pending';
  }

  /**
   * {@inheritDoc}
   */
  protected function accessOp(TransactionInterface $transaction, AccountInterface $account = NULL) : bool {
    if ($account->id() == 1) {
      return TRUE;
    }
    return $this->transactionRelativeManager
      ->isRelative($transaction, $account, $this->configuration['access']);
  }

  /**
   * {@inheritDoc}
   */
  public function execute($transaction = NULL) {
    mcapi_signature_service($transaction)->signOff();
    parent::execute($transaction);
  }

}
