<?php

namespace Drupal\mcapi\Element;

use Drupal\mcapi\Entity\Currency;
use Drupal\mcapi\Mcapi;
use Drupal\Core\Render\Element\FormElement;
use Drupal\Core\Render\Element\Checkboxes;
use Drupal\Core\Form\FormStateInterface;
use \Drupal\Core\Render\Element\Select;

/**
 * Provides a widget to select currencies.
 *
 * @FormElement("mcapi_currency_select")
 */
class CurrencySelect extends FormElement {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    return array(
      '#input' => TRUE,
      '#process' => [
        [get_class($this), 'processCurrcodes'],
      ],
      '#theme_wrappers' => ['form_element'],
      '#multiple' => FALSE,
    );
  }

  /**
   * Process callback.
   */
  public static function processCurrcodes($element, FormStateInterface $form_state, $complete_form) {
    if (empty($element['#options'])) {
      if (!empty($element['#curr_ids'])) {
        // Shows the intersection of all currencies and currencies provided.
        $element['#options'] = array_map(
          function($curr_id) {Currency::load($curr_id)->name;},
          $element['#curr_ids']
        );
      }
      elseif ($element['#options'] == 'all') {
        $element['#options'] = Mcapi::entityOptions('mcapi_currency');
      }
      else {
        $element['#options'] = [];
      }
    }
    if (count($element['#options']) < 2) {
      // For some reason the #value and #default_value properties don't appear in the form submission
      $element['#type'] = 'hidden';
      $element['#value'] = key($element['#options']);
      $element['#pre_render'] = [['Drupal\Core\Render\Element\Hidden', 'preRenderHidden']];
      $element['#theme'] = 'input__hidden';
      unset($element['#theme_wrappers']);
    }
    elseif ($element['#multiple']) {
      // Have to do some of the checkbox processing manually coz we missed it.
      $element['#type'] = 'checkboxes';
      $element['#value'] = array_filter($element['#default_value']);
      $element['#theme_wrappers'] = ['checkboxes'];
      $element['#pre_render'] = [['Drupal\Core\Render\Element\Checkboxes', 'preRenderCompositeFormElement']];
      $element = Checkboxes::processCheckboxes($element, $form_state, $complete_form);
    }
    else {
      $element['#theme'] = 'select';
      $element['#pre_render'] = [['Drupal\Core\Render\Element\Select', 'preRenderSelect']];
      $element = Select::processSelect($element, $form_state, $complete_form);
    }
    return $element;
  }

}
