<?php

namespace Drupal\mcapi\Element;

use Drupal\mcapi\Entity\Wallet;
use Drupal\Core\Render\Element\Fieldset;
use \Drupal\mcapi\Entity\Currency;
use \Drupal\mcapi\Entity\CurrencyInterface;

/**
 * Show all the wallets ordered somehow, + list showing the most and/or least.
 *
 * @RenderElement("mcapi_ordered_wallets")
 */
class OrderedWallets extends Fieldset {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $info = parent::getInfo();
    $info['#pre_render'][] = ['\Drupal\mcapi\Element\OrderedWallets', 'preRender'];
    $info += [
      '#depth' => 10,
      '#users_only' => TRUE,
      '#format_vals' => FALSE,
    // Show the rankings.
      '#top' => 5,
      '#attributes' => ['class' => ['ordered-wallets']],
    ];
    return $info;
  }

  /**
   * Prerender callback.
   */
  public static function preRender($element) {
    static $i = 0;
    // Put the largest values first
    arsort($element['#data']);
    $currency = Currency::load($element['#curr_id']);
    $data = [];
    foreach (array_slice($element['#data'], 0, $element['#top'], TRUE) as $wid => $raw_value) {
      $name = Wallet::load($wid)->label();
      if ($element['#format_vals']) {
        $val = $currency->format($raw_value, CurrencyInterface::DISPLAY_PLAIN);
      }
      else {
        $val = $raw_value;
      }
      $data[(string)$name] = $val;
    }
    $element['chart'] = [
      '#theme' => 'ordered_wallets',
      '#id' => 'ordered_wallets_' . $currency->id() . '_' . $i++,
      '#values' => $data,
      '#width' => 200,
      // The gChart axis labels don't show smaller than 125px
      '#height' => 125,
      '#class' => ['ordered-wallets'],
    ];
    if ($element['#format_vals']) {
      $tick = static::getTick($element['#data']);
      $element['chart']['#vticks'][$tick] = $currency->format($tick, CurrencyInterface::DISPLAY_NORMAL);
    }
    return $element;
  }

  /**
   * Get a nice round number to as the axis maximum.
   *
   * @param array $vals
   *   The values to be represented.
   *
   * @return int
   *   The raw value to put on the axis.
   */
  public static function getTick(array $vals) {
    if (empty($vals)) {
      $vals[] = 100;
    }
    $max = max($vals);
    $tick = str_pad(1, strlen($max), '0');
    $val = 0;
    while ($val < $max - $tick) {
      $val += $tick;
    }
    return $val;
  }

}
