<?php

namespace Drupal\mcapi\Event;

use Drupal\mcapi\Entity\Transaction;
use Symfony\Component\EventDispatcher\GenericEvent;

/**
 * Event which is fired before a new transaction is validated.
 *
 * @see \Drupal\mcapi\Entity\Transaction::assemble()
 */
class TransactionAssembleEvent extends GenericEvent {

  const EVENT_NAME = 'mcapi_transaction.assemble';

  public $children = [];

  /**
   * Add a child transaction.
   *
   * @param array $props
   *   The new child transaction.
   */
  public function addChildTransaction(array $props) {
    try {
      $this->getSubject()->createChild($props);
    }
    catch(\Exception $e) {
      \Drupal::logger('mcapi')->warning($e->getMessage());
    }
  }

  /*
   * Less elegant way
   * @deprecated
   */
  public function addChild(Transaction $child) {
    \Drupal::logger('mcapi')->warning('TransactionAssembleEvent::addChild($transaction) is deprecated. Please see TransactionAssembleEvent::addChildTransaction($props)');
    $parent_transaction = $this->getSubject();
    $child->uuid->applyDefaultValue(FALSE);
    $child->type->target_id = 'inherit';
    $child->state->target_id = $parent_transaction->state->target_id;
    $parent_transaction->children->appendItem($child);
  }

}
